from typing import Optional, List
from pydantic import Field
from luksdk.luksdk_model import LukSDKModel

class Game(LukSDKModel):
    """游戏信息"""
    game_id: str = Field(alias="g_id")  # 游戏 ID
    game_name: str = Field(alias="g_name")  # 游戏名称
    game_icon: str = Field(alias="g_icon")  # 游戏图标
    game_url: str = Field(alias="g_url")  # 游戏在线加载 URL

class ResponseData(LukSDKModel):
    """响应数据"""
    game_list: List[Game] = Field(alias="game_list")  # 游戏列表

class Response(LukSDKModel):
    """获取游戏服务列表响应"""
    code: int = Field(alias="code")  # 请求状态码，当值为 0 时表示请求成功
    msg: Optional[str] = Field(None, alias="msg")  # 请求状态说明
    data: ResponseData = Field(alias="data")  # 响应数据

class Request(LukSDKModel):
    """获取游戏服务列表请求"""
    app_id: Optional[int] = Field(None, alias="c_id")  # App ID
    timestamp: Optional[int] = Field(None, alias="timestamp")  # 时间戳
    sign: Optional[str] = Field(None, alias="sign")  # 签名
