from typing import Optional, List, Union
from pydantic import Field
from luksdk.enums import Identity
from luksdk.luksdk_model import LukSDKModel


class JoinGame(LukSDKModel):
    """加入游戏事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID
    seat: Optional[int] = Field(None, alias="seat")  # 座位号
    ready: Optional[bool] = Field(None, alias="ready")  # 是否准备
    auto_start_num: Optional[int] = Field(None, alias="auto_start_num")  # 自动开始人数


class LeaveGame(LukSDKModel):
    """离开游戏事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID


class ChangeReadyStatus(LukSDKModel):
    """改变准备状态事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID
    is_prepare: Optional[bool] = Field(None, alias="is_prepare")  # 是否准备


class KickPlayer(LukSDKModel):
    """踢出玩家事件"""
    op_user_id: Optional[str] = Field(None, alias="op_user_id")  # 操作用户 ID
    user_id: str = Field(alias="user_id")  # 被踢用户 ID
    reason: Optional[str] = Field(None, alias="reason")  # 踢出原因


class StartGame(LukSDKModel):
    """开始游戏事件"""
    op_user_id: Optional[str] = Field(None, alias="op_user_id")  # 操作用户 ID
    force: Optional[bool] = Field(None, alias="force")  # 是否强制开始
    start_ext: Optional[str] = Field(None, alias="start_ext")  # 开始游戏扩展数据


class ForceCloseGame(LukSDKModel):
    """强制关闭游戏事件"""
    op_user_id: Optional[str] = Field(None, alias="op_user_id")  # 操作用户 ID
    clear_seat: Optional[bool] = Field(None, alias="clear_seat")  # 是否清空座位


class ChangeRoomSetting(LukSDKModel):
    """改变房间设置事件"""
    op_user_id: Optional[str] = Field(None, alias="op_user_id")  # 操作用户 ID
    room_setting: str = Field(alias="room_setting")  # 房间设置


class ChangeUserIdentity(LukSDKModel):
    """改变用户身份事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID
    identity: Identity = Field(alias="identity")  # 用户身份


class RoomSeatSync(LukSDKModel):
    """房间座位同步事件"""


class RefreshUserInfo(LukSDKModel):
    """刷新用户信息事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID


class QuickStartGame(LukSDKModel):
    """快捷开始游戏事件"""
    setting: Optional[str] = Field(None, alias="setting")  # 游戏设置
    start_game: Optional[bool] = Field(None, alias="start_game")  # 是否开始游戏
    user_ids: Optional[List[str]] = Field(None, alias="user_ids")  # 用户 ID 列表


class IssueProps(LukSDKModel):
    """发放道具事件"""
    unique_id: str = Field(alias="unique_id")  # 唯一 ID
    user_id: str = Field(alias="user_id")  # 用户 ID
    details: Optional[List['PublishControlEventRequest.IssueProps.Detail']] = Field(None, alias="details")  # 道具详情列表
    extra: Optional[str] = Field(None, alias="extra")  # 扩展信息

    class Detail(LukSDKModel):
        """发放道具详情"""
        prop_id: str = Field(alias="prop_id")  # 道具 ID
        num: int = Field(alias="num")  # 数量
        duration: Optional[int] = Field(None, alias="duration")  # 持续时间
        duration_reset: Optional[bool] = Field(None, alias="duration_reset")  # 持续时间是否重置


class FetchBagStatus(LukSDKModel):
    """获取背包状态事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID


class FetchBagStatusResponseProp(LukSDKModel):
    """道具信息"""
    expire_time: Optional[int] = Field(None, alias="expire_time")  # 过期时间
    is_equipped: Optional[bool] = Field(None, alias="is_equipped")  # 是否已装备
    num: Optional[int] = Field(None, alias="num")  # 数量
    prop_id: Optional[str] = Field(None, alias="prop_id")  # 道具 ID
    prop_type: Optional[int] = Field(None, alias="prop_type")  # 道具类型


class FetchBagStatusResponse(LukSDKModel):
    """获取背包状态响应"""
    prop_list: Optional[List[FetchBagStatusResponseProp]] = Field(None, alias="props")  # 道具列表 (字段名对应Java propList)


class QueryIssuePropStatus(LukSDKModel):
    """查询发放道具状态事件"""
    unique_id: str = Field(alias="unique_id")  # 唯一 ID


class QueryIssuePropStatusDetail(LukSDKModel):
    """查询发放道具状态详情"""
    prop_id: Optional[str] = Field(None, alias="prop_id")  # 道具 ID
    num: Optional[int] = Field(None, alias="num")  # 数量
    duration: Optional[int] = Field(None, alias="duration")  # 持续时间
    duration_reset: Optional[bool] = Field(None, alias="duration_reset")  # 持续时间是否重置


class QueryIssuePropStatusResponse(LukSDKModel):
    """查询发放道具状态响应"""
    app_id: Optional[int] = Field(None, alias="app_id")  # App ID
    unique_id: Optional[str] = Field(None, alias="unique_id")  # 唯一 ID
    game_id: Optional[int] = Field(None, alias="game_id")  # 游戏 ID
    user_id: Optional[str] = Field(None, alias="user_id")  # 用户 ID
    created_time: Optional[int] = Field(None, alias="created_time")  # 创建时间
    status: Optional[int] = Field(None, alias="status")  # 状态
    details: Optional[List[QueryIssuePropStatusDetail]] = Field(None, alias="details")  # 详情列表
    extra: Optional[str] = Field(None, alias="extra")  # 扩展信息


class EquippedProp(LukSDKModel):
    """装备道具事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID
    equipped_prop_id: str = Field(alias="equipped_prop_id")  # 装备道具 ID


class UnequippedProp(LukSDKModel):
    """卸下道具事件"""
    user_id: str = Field(alias="user_id")  # 用户 ID
    unequipped_prop_id: str = Field(alias="unequipped_prop_id")  # 卸下道具 ID


class Request(LukSDKModel):
    """发布控制事件请求"""
    app_id: Optional[int] = Field(None, alias="app_id")  # App ID
    game_id: int = Field(alias="game_id")  # 游戏 ID
    room_id: Optional[str] = Field(None, alias="room_id")  # 房间 ID
    type: int = Field(alias="type")  # 事件类型
    data: str = Field(alias="data")  # 事件数据 JSON
    timestamp: Optional[int] = Field(None, alias="timestamp")  # 秒级时间戳
    sign: Optional[str] = Field(None, alias="sign")  # 请求签名


class Response(LukSDKModel):
    """发布控制事件响应"""
    code: int = Field(alias="code")  # 请求状态码，当值为 0 时表示请求成功
    msg: Optional[str] = Field(None, alias="msg")  # 请求状态说明
    data: Optional[Union[FetchBagStatusResponse, QueryIssuePropStatus, dict]] = Field(None, alias="data")  # 响应数据
