from typing import Optional, List
from pydantic import Field

from luksdk.luksdk_model import LukSDKModel


class Event(LukSDKModel):
    """通知事件"""
    type: int = Field(alias="type")  # 事件类型
    data: str = Field(alias="data")  # 事件数据


class ResponseData(LukSDKModel):
    """响应数据"""
    list: List[Event] = Field(alias="list")  # 事件列表


class Response(LukSDKModel):
    """查询通知事件响应"""
    code: int = Field(alias="code")  # Code 0 表示成功
    msg: Optional[str] = Field(None, alias="msg")  # Msg 消息
    data: ResponseData = Field(alias="data")  # Data 数据


class Request(LukSDKModel):
    """查询通知事件请求"""
    app_id: int = Field(alias="app_id")  # App ID
    end_at: Optional[int] = Field(None, alias="end_at")  # 结束时间，可基于秒级结束时间戳过滤
    game_id: int = Field(alias="game_id")  # 游戏 ID
    page_no: int = Field(alias="page_no")  # 页码
    page_size: int = Field(alias="page_size")  # 每页数量
    room_id: Optional[str] = Field(None, alias="room_id")  # 房间 ID，可基于房间 ID 过滤
    sign: str = Field("", alias="sign")  # 请求签名
    start_at: Optional[int] = Field(None, alias="start_at")  # 开始时间，可基于秒级开始时间戳过滤
    timestamp: Optional[int] = Field(None, alias="timestamp")  # 秒级时间戳
    type: Optional[int] = Field(None, alias="type")  # 事件类型，可基于事件类型过滤，具体参考游戏通知事件接口