from typing import Optional
from pydantic import Field

from luksdk.luksdk_model import LukSDKModel


class Order(LukSDKModel):
    """订单数据"""
    app_id: Optional[int] = Field(None, alias="app_id")  # App ID 
    app_order_id: Optional[str] = Field(None, alias="app_order_id")  # 渠道订单 ID
    game_order_id: Optional[str] = Field(None, alias="game_order_id")  # 游戏订单 ID
    user_id: Optional[str] = Field(None, alias="user_id")  # 用户 ID
    item_id: Optional[str] = Field(None, alias="item_id")  # 道具 ID
    num: Optional[int] = Field(None, alias="num")  # 数量 
    coins_cost: Optional[int] = Field(None, alias="coins_cost")  # 金币消耗
    coins_award: Optional[int] = Field(None, alias="coins_award")  # 金币奖励
    gain: Optional[int] = Field(None, alias="gain")  # 收益
    anchor_draw: Optional[int] = Field(None, alias="anchor_draw")  # 主播抽成
    coins_official_draw: Optional[int] = Field(None, alias="coins_official_draw")  # 官方抽成 
    pay_status: Optional[int] = Field(None, alias="pay_status")  # 支付状态
    pay_game_status: Optional[int] = Field(None, alias="pay_game_status")  # 游戏支付状态
    create_time: Optional[int] = Field(None, alias="create_time")  # 创建时间
    ext: Optional[str] = Field(None, alias="ext")  # 扩展信息


class Response(LukSDKModel):
    """查询订单响应"""
    code: int = Field(alias="code")  # 请求状态码，当值为 0 时表示请求成功
    data: Order = Field(alias="data")  # 响应数据
    msg: Optional[str] = Field(None, alias="msg")  # 请求状态说明


class Request(LukSDKModel):
    """查询订单请求"""
    app_id: Optional[int] = Field(None, alias="app_id")  # App ID
    game_id: int = Field(alias="game_id")  # 游戏 ID
    app_order_no: Optional[str] = Field(None, alias="app_order_no")  # 渠道订单 ID，和 game_order_no 二选一
    game_order_no: Optional[str] = Field(None, alias="game_order_no")  # 游戏订单 ID，和 app_order_no 二选一
    nonce: Optional[str] = Field(None, alias="nonce")  # 随机字符串
    timestamp: Optional[int] = Field(None, alias="timestamp")  # 秒级时间戳
    sign: Optional[str] = Field(None, alias="sign")  # 请求签名
