from pydantic import Field
from typing import Optional, List
from pydantic import BaseModel

from luksdk.luksdk_model import LukSDKModel


class Order(LukSDKModel):
    """创建渠道订单请求数据项"""
    app_id: int = Field(alias="c_id")  # App ID
    game_id: int = Field(alias="game_id")  # 游戏 ID
    room_id: Optional[str]  # 房间 ID
    user_id: str = Field(alias="c_uid")  # 用户 ID
    coins_cost: Optional[int] = None  # 预扣货币量
    ext: Optional[str] = None  # 扩展信息
    game_order_id: str  # 游戏订单 ID
    timestamp: Optional[int] = None  # 秒级时间戳
    token: str  # Token，长期有效访问令牌


class OrderResult(BaseModel):
    """创建渠道订单响应数据项"""
    user_id: str = Field(alias="c_uid")  # 用户 ID
    coins: Optional[int] = None  # 剩余货币量
    order_id: str  # 渠道方订单 ID
    status: int  # 订单状态


class Request(BaseModel):
    """创建渠道订单请求"""
    data: List[Order]  # 订单数据列表
    nonce: Optional[str] = None  # 随机字符串
    timestamp: Optional[int] = None  # 秒级时间戳
    sign: str = ""  # 请求签名


class Response(BaseModel):
    """创建渠道订单响应"""
    code: int = 0  # 请求状态码，当值为 0 时表示请求成功
    msg: Optional[str] = None  # 请求状态说明
    data: List[OrderResult] = []
