from typing import Optional

from pydantic import Field

from luksdk.enums import Identity
from luksdk.luksdk_model import LukSDKModel


class UserInfo(LukSDKModel):
    """获取渠道用户信息响应数据"""
    user_id: str = Field(alias="c_uid")  # 用户 ID
    avatar: str = ""  # 头像
    name: str = ""  # 用户名
    coins: int = 0  # 货币数量
    identity: Optional[Identity] = None  # 用户身份


class Request(LukSDKModel):
    """获取渠道用户信息请求"""
    app_id: int = Field(alias="c_id")  # App ID
    user_id: str = Field(alias="c_uid")  # 用户 ID
    timestamp: Optional[int] = None  # 秒级时间戳 (对应Java Long类型)
    sign: str = ""  # 请求签名

class Response(LukSDKModel):
    """获取渠道用户信息响应"""
    code: int = 0  # 请求状态码，当值为 0 时表示请求成功
    msg: Optional[str] = None  # 请求状态说明
    data: Optional[UserInfo] = None
