from typing import Optional, List

from pydantic import Field

from luksdk.luksdk_model import LukSDKModel


class Order(LukSDKModel):
    """通知渠道订单请求数据项"""
    app_id: int = Field(alias="c_id")  # App ID
    user_id: str = Field(alias="c_uid")  # 用户 ID
    coins_award: Optional[int] = None  # 奖励货币量，一些场景用户获得奖励需要发放的货币量
    coins_cost: Optional[int] = None  # 预扣货币量，订单创建时的预扣货币量
    game_id: int = Field(alias="g_id")  # 游戏 ID
    game_order_id: str  # 游戏订单 ID
    status: int  # 订单状态
    timestamp: Optional[int] = None  # 秒级时间戳
    token: str  # Token，长期有效访问令牌


class OrderResult(LukSDKModel):
    """通知渠道订单响应数据项"""
    user_id: str = Field(alias="c_uid")  # 用户 ID
    coins: Optional[int] = None  # 剩余货币量
    order_id: str  # 渠道方订单 ID


class Request(LukSDKModel):
    """通知渠道订单请求"""
    data: List[Order]  # 订单列表
    nonce: Optional[str] = None  # 随机字符串
    timestamp: Optional[int] = None  # 秒级时间戳
    sign: str = ""  # 请求签名


class Response(LukSDKModel):
    """通知渠道订单响应"""
    code: int = 0  # 请求状态码，当值为 0 时表示请求成功
    data: List[OrderResult] = []  # 订单响应列表
    msg: Optional[str] = None  # 请求状态说明
