from typing import Optional, List, Dict
from luksdk.luksdk_model import LukSDKModel


# 事件数据模型
class StartGame(LukSDKModel):
    """开始游戏事件数据"""
    op_user_id: Optional[str] = None  # 操作用户 ID
    start_ext: Optional[str] = None  # 开始游戏透传数据
    start_unix_sec: int  # 游戏开始时间，秒级时间戳
    user_ids: List[str]  # 参与游戏的玩家 ID 列表


class GameOverUserResult(LukSDKModel):
    """游戏结束用户结果"""
    escape: Optional[bool] = None  # 是否逃跑
    rank: Optional[int] = None  # 玩家排名
    score: Optional[int] = None  # 玩家得分
    status: Optional[int] = None  # 玩家状态
    trust: Optional[bool] = None  # 是否托管


class GameOver(LukSDKModel):
    """游戏结束事件数据"""
    cost_coins: Optional[int] = None  # 本局消耗货币数
    end_ext: Optional[str] = None  # 结束扩展信息
    end_type: Optional[int] = None  # 游戏结束类型
    end_unix_sec: int  # 游戏结束时间，秒级时间戳
    op_user_id: Optional[str] = None  # 操作用户 ID
    start_ext: Optional[str] = None  # 开始游戏透传数据
    start_unix_sec: int  # 游戏开始时间，秒级时间戳
    user_results: List[GameOverUserResult]  # 玩家游戏结果


class RoomUserChange(LukSDKModel):
    """房间用户变更事件数据"""
    gaming: Optional[bool] = None  # 是否游戏进行中
    ob_user_ids: Optional[List[str]] = None  # 观众用户 ID 列表
    player_state: Optional[Dict[str, bool]] = None  # 玩家准备状态
    type: Optional[int] = None  # 变更类型
    user_ids: Optional[List[str]] = None  # 变更的用户 ID 列表


class RoomSettingChange(LukSDKModel):
    """房间设置变更事件数据"""
    op_user_id: Optional[str] = None  # 操作用户 ID
    setting: str  # 房间设置


class RoomSeatSync(LukSDKModel):
    """房间座位同步事件数据"""
    seat_user_ids: Optional[Dict[int, str]] = None  # 座位用户 ID 集合


class RoomGameFeature(LukSDKModel):
    """房间游戏特色事件数据"""
    feature: str  # 游戏特色事件 JSON


class RoomPropEquip(LukSDKModel):
    """房间道具装备事件数据"""
    equipped_prop_id: Optional[str] = None  # 装配的道具 ID
    unequipped_prop_id: Optional[str] = None  # 卸下的道具 ID
    user_id: str  # 用户 ID


class Request(LukSDKModel):
    """通知事件请求"""
    app_id: int  # App ID
    game_id: int  # 游戏 ID
    room_id: str  # 房间 ID
    round_id: str  # 游戏局次 ID
    sign: str  # 请求签名
    timestamp: Optional[int] = None  # 秒级时间戳
    type: int  # 事件类型
    data: str  # 事件数据 JSON


class Response(LukSDKModel):
    """通知事件响应"""
    code: int = 0  # 请求状态码，当值为 0 时表示请求成功
    msg: Optional[str] = None  # 请求状态说明
