from typing import Optional, List, Dict
from pydantic import Field
from luksdk.luksdk_model import LukSDKModel


# 游戏通知数据模型
class GameStartBeforeData(LukSDKModel):
    """游戏开始前数据"""
    game_setting: Optional[str] = None  # 游戏当前设置
    notify_action: int  # 操作
    player_ready_status: Dict[str, bool]  # 是否已准备，字典键指向用户ID
    room_id: str  # 房间ID
    round_id: str  # 游戏局次ID


class GameRunningData(LukSDKModel):
    """游戏进行中数据"""
    notify_action: int  # 操作
    player_num: int  # 玩家数量
    player_uids: List[str]  # 玩家ID列表
    room_id: str  # 房间ID
    round_id: str  # 游戏局次ID


class GameEndData(LukSDKModel):
    """游戏结束数据"""
    is_force_end: Optional[bool] = None  # 是否强制结束游戏
    notify_action: int  # 操作
    player_score: Dict[str, int]  # 玩家分数，字典键指向用户ID
    rank: List[str]  # 排名，根据排名排序的玩家ID数组
    room_id: str  # 房间ID
    round_id: str  # 游戏局次ID


class Request(LukSDKModel):
    """通知游戏请求"""
    app_id: int = Field(alias="c_id")  # App ID
    data: str  # 通知数据
    ext: Optional[str] = None  # 房间透传字段
    game_id: int = Field(alias="g_id")  # 游戏 ID
    notify_type: int  # 通知类型枚举
    sign: str  # 请求签名
    timestamp: Optional[int] = None  # 秒级时间戳


class NotifyGameResponse(LukSDKModel):
    """通知游戏响应"""
    code: int = 0  # 请求状态码，当值为 0 时表示请求成功
    msg: Optional[str] = None  # 请求状态说明
