from typing import Optional

from pydantic import Field

from luksdk.luksdk_model import LukSDKModel


class Token(LukSDKModel):
    """刷新渠道令牌响应数据"""
    token: str  # 新的访问令牌
    left_time: int  # 剩余有效时间（秒）


class Request(LukSDKModel):
    """刷新渠道令牌请求"""
    app_id: int = Field(alias="c_id")  # App ID
    user_id: str = Field(alias="c_uid")  # 用户 ID
    timestamp: Optional[int] = None  # 秒级时间戳
    sign: str = ""  # 请求签名
    token: str  # 当前令牌
    left_time: int  # 剩余有效时间


class Response(LukSDKModel):
    """刷新渠道令牌响应"""
    code: int = 0  # 请求状态码，当值为 0 时表示请求成功
    msg: Optional[str] = None  # 请求状态说明
    data: Optional[Token] = None
