
class LukSDKException(Exception):
    """LukSDK 异常类"""

    def __init__(self, code, msg):
        self.code = code
        self.msg = msg
        Exception.__init__(self, "[{0}] {1}".format(code, msg))

    def with_detail(self, *details):
        """添加详细信息"""
        if details:
            detail_str = str(details[0]) if len(details) == 1 else str(details)
            new_msg = "{0}: {1}".format(self.msg, detail_str)
            return LukSDKException(self.code, new_msg)
        return self


class LukSDKExceptions:
    """预定义错误常量"""
    INTERNAL_ERROR = LukSDKException(100000, "LukSDK: 服务器内部异常")
    PARAM_ERROR = LukSDKException(100001, "LukSDK: 参数错误")
    RETRY_ERROR = LukSDKException(100002, "LukSDK: 请稍后再试")
    CONTENT_ERROR = LukSDKException(100003, "LukSDK: 资源不存在")
    CHANNEL_ERROR = LukSDKException(100004, "LukSDK: 渠道已禁用")
    SIGN_ERROR = LukSDKException(100005, "LukSDK: 签名校验失败")
    LOGIN_ERROR = LukSDKException(100006, "LukSDK: 未登录或 Token 已过期")
    CALLBACK_ERROR = LukSDKException(100007, "LukSDK: 渠道方回调地址响应解析失败")

